using System.Collections.Generic;
using System.Text.RegularExpressions;

using PRoCon.Core.Plugin;

namespace PRoConEvents {
	
	public class CPlayerJoinMessage : PRoConPluginAPI, IPRoConPluginInterface {

		private bool m_enableJoiningMessage;
		private bool m_enableLeftMessage;
        private bool m_isPluginEnabled;
		
		public CPlayerJoinMessage (){
			
			this.m_enableJoiningMessage = true;
			this.m_enableLeftMessage = false;
            this.m_isPluginEnabled = false;
		}
		
		public string GetPluginName() {
            return "PlayerJoinMessage";
        }
		
		public string GetPluginVersion() {
            return "1.0.0";
        }
		
        public string GetPluginAuthor() {
            return "Flash_Hit";
        }
		
        public string GetPluginWebsite() {
            return "playvu.com/";
        }
		
		public string GetPluginDescription() {
            return @"
<h2>Description</h2>
    <p>Chat message for joining/leaving players.</p>
	
<h2>Settings</h2>    
		<blockquote><h4>Enable Joining message</h4>Enable/Disable the player joining chat message.</blockquote>
		<blockquote><h4>Enable Leaving message</h4>Enable/Disable the player leaving chat message.</blockquote>";
        }
		
        public void OnPluginLoaded(string strHostName, string strPort, string strPRoConVersion) {
			
			this.RegisterEvents(this.GetType().Name, "OnPlayerJoin", "OnPlayerLeft");
        }
		
		public void OnPluginEnable() {
            this.ExecuteCommand("procon.protected.pluginconsole.write", "[^bPlayerJoinMessage^n] Plugin ^2Enabled!");
            this.m_isPluginEnabled = true;
        }

        public void OnPluginDisable() {
            this.ExecuteCommand("procon.protected.pluginconsole.write", "[^bPlayerJoinMessage^n] Plugin ^1Disabled!" );

            this.m_isPluginEnabled = false;
        }
		
		public List<CPluginVariable> GetDisplayPluginVariables() {

            List<CPluginVariable> lstReturn = new List<CPluginVariable>();

			lstReturn.Add(new CPluginVariable("Enable Player Joining Message", typeof(bool), m_enableJoiningMessage));
			lstReturn.Add(new CPluginVariable("Enable Player Left Message", typeof(bool), m_enableLeftMessage));
		
            return lstReturn;
        }

        public List<CPluginVariable> GetPluginVariables() {
            return GetDisplayPluginVariables();
        }
		
		public void SetPluginVariable(string strVariable, string strValue) {
			if (Regex.Match(strVariable, @"Enable Player Joining Message").Success)
            {
				bool tmp_enableJoiningMessage = true;
                bool.TryParse(strValue, out tmp_enableJoiningMessage);
				m_enableJoiningMessage = tmp_enableJoiningMessage;
				if (m_enableJoiningMessage == true){
					this.ExecuteCommand("procon.protected.pluginconsole.write", "[^bPlayerJoinMessage^n] Player:Joining Chat message ^2enabled" );
				}else{
					this.ExecuteCommand("procon.protected.pluginconsole.write", "[^bbPlayerJoinMessage^n] Player:Joining Chat message ^1disabled" );
				}
            } 	
			else if (Regex.Match(strVariable, @"Enable Player Left Message").Success)
            {
				bool tmp_enableLeftMessage = true;
                bool.TryParse(strValue, out tmp_enableLeftMessage);
				m_enableLeftMessage = tmp_enableLeftMessage;
				if (m_enableLeftMessage == true){
					this.ExecuteCommand("procon.protected.pluginconsole.write", "[^bPlayerJoinMessage^n] Player:Left Chat message ^2enabled" );
				}else{
					this.ExecuteCommand("procon.protected.pluginconsole.write", "[^bPlayerJoinMessage^n] Player:Left Chat message ^1disabled" );
				}
            } 	
        }
		
		public void OnPlayerJoin (string soldierName){
			if(m_isPluginEnabled == true && m_enableJoiningMessage == true)
			{
				this.ExecuteCommand("procon.protected.send", "admin.say", soldierName + " has joined the server", "all");
			}
		}
		
		public void OnPlayerLeft (CPlayerInfo playerInfo){
			if(m_isPluginEnabled == true && m_enableLeftMessage == true)
			{
				this.ExecuteCommand("procon.protected.send", "admin.say", playerInfo.SoldierName + " has left the server", "all");
			}
		}

	}
}